==> assemblyline-core-4.2.0.72.tar.gz: assemblyline-core-4.2.0.72/assemblyline_core/replay/loader/run.py <==
import shelve
import os

from assemblyline_core.replay.client import APIClient, DirectClient
from assemblyline_core.replay.replay import ReplayBase


class ReplayLoader(ReplayBase):
    def __init__(self):
        super().__init__("assemblyline.replay_loader")

        # Create cache directory
        os.makedirs(self.replay_config.loader.working_directory, exist_ok=True)

        # Create/Load the cache
        self.cache = shelve.open(os.path.join(self.replay_config.loader.working_directory, 'loader_cache.db'))
        if 'files' not in self.cache:
            self.cache['files'] = set()

        # Load client
        if self.replay_config.loader.client.type == 'direct':
            self.log.info("Using direct database access client")
            self.client = DirectClient(self.log)
        elif self.replay_config.loader.client.type == 'api':
            self.log.info(f"Using API access client to ({self.replay_config.loader.client.options.host})")
            self.client = APIClient(self.log, **self.replay_config.loader.client.options.as_primitives())
        else:
            raise ValueError(f'Invalid client type ({self.replay_config.loader.client.type}). '
                             'Must be either \'api\' or \'direct\'.')

    def load_files(self):
        while self.running:
            new_files = False
            new_cache = set()
            for root, _, files in os.walk(self.replay_config.loader.input_directory, topdown=False):
                for name in files:
                    file_path = os.path.join(root, name)

                    # Cache file
                    new_cache.add(file_path)

                    if file_path not in self.cache['files']:
                        self.log.info(f'Queueing file: {file_path}')
                        self.client.put_file(file_path)
                        new_files = True

                    # Cache file
                    self.cache['files'].add(file_path)

            # Cleanup cache
            self.cache['files'] = new_cache

            if not new_files:
                self.sleep(5)

    def try_run(self):
        threads = {
            # Pull in completed submissions
            'File loader': self.load_files
        }

        self.maintain_threads(threads)

    def stop(self):
        self.cache.close()
        return super().stop()


if __name__ == '__main__':
    with ReplayLoader() as replay:
        replay.serve_forever()

==> assemblyline-core-4.2.1.dev193.tar.gz: assemblyline-core-4.2.1.dev193/assemblyline_core/replay/loader/run.py <==
import shelve
import os

from assemblyline_core.replay.client import APIClient, DirectClient
from assemblyline_core.replay.replay import ReplayBase


class ReplayLoader(ReplayBase):
    def __init__(self):
        super().__init__("assemblyline.replay_loader")

        # Make sure all directories exist
        os.makedirs(self.replay_config.loader.working_directory, exist_ok=True)
        os.makedirs(self.replay_config.loader.input_directory, exist_ok=True)
        os.makedirs(self.replay_config.loader.failed_directory, exist_ok=True)

        # Create/Load the cache
        self.cache = shelve.open(os.path.join(self.replay_config.loader.working_directory, 'loader_cache.db'))
        if 'files' not in self.cache:
            self.cache['files'] = set()

        # Load client
        if self.replay_config.loader.client.type == 'direct':
            self.log.info("Using direct database access client")
            self.client = DirectClient(self.log)
        elif self.replay_config.loader.client.type == 'api':
            self.log.info(f"Using API access client to ({self.replay_config.loader.client.options.host})")
            self.client = APIClient(self.log, **self.replay_config.loader.client.options.as_primitives())
        else:
            raise ValueError(f'Invalid client type ({self.replay_config.loader.client.type}). '
                             'Must be either \'api\' or \'direct\'.')

    def load_files(self, once=False):
        while self.running:
            new_files = False
            new_cache = set()
            for root, _, files in os.walk(self.replay_config.loader.input_directory, topdown=False):
                for name in files:
                    # Unexpected files that could be the result of external transfer mechanisms
                    if name.startswith('.') or not name.endswith('.al_bundle'):
                        continue

                    file_path = os.path.join(root, name)

                    # Cache file
                    new_cache.add(file_path)

                    if file_path not in self.cache['files']:
                        self.log.info(f'Queueing file: {file_path}')
                        self.client.put_file(file_path)
                        new_files = True

                    # Cache file
                    self.cache['files'].add(file_path)

            # Cleanup cache
            self.cache['files'] = new_cache

            if once:
                break

            if not new_files:
                self.sleep(5)

    def try_run(self):
        threads = {
            # Pull in completed submissions
            'File loader': self.load_files
        }

        self.maintain_threads(threads)

    def stop(self):
        self.cache.close()
        return super().stop()


if __name__ == '__main__':
    with ReplayLoader() as replay:
        replay.serve_forever()
